package routing

import (
	"testing"

	"github.com/stretchr/testify/assert"
	"github.com/stretchr/testify/require"
	"orus.io/xbus/xbus-stdlib/service"
)

func TableStoreTestSuite(t *testing.T, factory TableStoreFactory, settings service.Settings) {
	t.Run("get-empty", func(t *testing.T) {
		store, err := factory("store.", settings)
		require.NoError(t, err)

		_, err = store.Get("empty")
		assert.EqualError(t, err, "no such key")
	})
	t.Run("set", func(t *testing.T) {
		store, err := factory("store.", settings)
		require.NoError(t, err)

		assert.NoError(t, store.Set("k1", "v1"))
	})
	t.Run("get", func(t *testing.T) {
		store, err := factory("store.", settings)
		require.NoError(t, err)

		v, err := store.Get("k1")
		assert.NoError(t, err)
		assert.Equal(t, "v1", v)
	})
	t.Run("delete", func(t *testing.T) {
		store, err := factory("store.", settings)
		require.NoError(t, err)

		require.NoError(t, store.Delete("k1"))

		_, err = store.Get("k1")
		assert.EqualError(t, err, "no such key")
	})
}
